/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 08917
 |                  NATIONAL YOUTH SURVEY (1979): WAVE 4
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 08917-0001-statasetup.do)
 |
 **************************************************************************/

set mem 8m  /* Allocating 8 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Youth Survey (1979): Wave 4, Dataset 0001"

#delimit ;
label define V1        1 "Male" 2 "Female" ;
label define V2        1 "Anglo" 2 "Black" 3 "Hispanic" 4 "American Indian"
                       5 "Asian" 6 "Other" ;
label define V7        1 "Moth/fath" 2 "Moth only" 3 "Fath only"
                       4 "Moth/Stepfath" 5 "Fath/Stepmoth" 6 "Spouse"
                       7 "Roommate" 8 "Boy/girl friend" 9 "Alone"
                       10 "Military" 11 "Other" 12 "Moth/oth rel/non"
                       13 "Fath/oth rel/non" 14 "Moth/fath oth rel/non"
                       15 "Relatives" ;
label define V8        1 "No" 2 "Yes" ;
label define V9        1 "No" 2 "Yes" ;
label define V10       1 "No" 2 "Yes" ;
label define V11       1 "No" 2 "Yes" ;
label define V12       1 "No" 2 "Yes" ;
label define V13       1 "No" 2 "Yes" ;
label define V14       1 "No" 2 "Yes" ;
label define V15       1 "No" 2 "Yes" ;
label define V16       1 "No" 2 "Yes" ;
label define V17       1 "No" 2 "Yes" ;
label define V18       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V19       0 "Less than once a wk" ;
label define V20       0 "Less than once a wk" ;
label define V21       1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V22       1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V23       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V24       0 "Less than once a wk" ;
label define V25       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V26       1 "No" 2 "Yes" ;
label define V27       1 "No" 2 "Yes" ;
label define V28       18 "Not in school" 19 "Adult education"
                       20 "GED program" 21 "Bus/sec school"
                       22 "Voc/tech school" 23 "Other" 24 "Military school" ;
label define V29       1 "No" 2 "Yes" ;
label define V30       18 "Not in school" 19 "Adult education"
                       20 "GED program" 21 "Bus/sec school"
                       22 "Voc/tech school" 23 "Other" 24 "Military school" ;
label define V31       1 "No" 2 "Yes" ;
label define V32       1 "Mostly F's" 2 "Mostly D's" 3 "Mostly C's"
                       4 "Mostly B's" 5 "Mostly A's" ;
label define V33       0 "Less than once a wk" ;
label define V34       0 "Less than once a wk" ;
label define V35       1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V36       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V37       1 "No" 2 "Yes" ;
label define V38       1 "Contact sport" 2 "Non-contact sport"
                       3 "Combination" ;
label define V39       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V40       0 "Less than once a wk" ;
label define V41       0 "Less than once a wk" ;
label define V42       1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V43       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V44       1 "No" 2 "Yes" ;
label define V45       1 "Service clubs" 2 "Rec/hobby/voc" 3 "Student govt"
                       4 "Journalistic" 5 "Drama/art/culture"
                       6 "Cheer/Pom-Pom/Pep" 7 "R.O.T.C." 8 "Other"
                       9 "Comb activities" 10 "Academic" 11 "Fraternity" ;
label define V46       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V47       0 "Less than once a wk" ;
label define V48       0 "Less than once a wk" ;
label define V49       1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V50       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V51       1 "Athlete" 2 "Activities mem" 3 "Social type"
                       4 "Good student" 5 "Average student" 6 "None of above"
                       7 "Other" ;
label define V52       1 "No" 2 "Yes" ;
label define V53       1 "Relig/church" 2 "Service clubs" 3 "Rec/athletic"
                       4 "Other" 5 "Comb of activities" 6 "Drama/art/culture" ;
label define V54       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V55       0 "Less than once a wk" ;
label define V56       0 "Less than once a wk" ;
label define V57       1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V58       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V59       1 "NIMH" 2 "LEAA" ;
label define V63       1 "No" 2 "Yes" ;
label define V64       1 "No" 2 "Yes" ;
label define V65       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V68       0 "Less than one wk" ;
label define V69       0 "Less than 1 hr" ;
label define V77       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V78       1 "No" 2 "Yes" ;
label define V79       1 "No" 2 "Yes" ;
label define V80       13 "Winter" 14 "Spring" 15 "Summer" 16 "Fall" ;
label define V82       1 "No" 2 "Yes" ;
label define V83       13 "Winter" 14 "Spring" 15 "Summer" 16 "Fall" ;
label define V85       1 "No" 2 "Yes" ;
label define V86       13 "Winter" 14 "Spring" 15 "Summer" 16 "Fall" ;
label define V88       1 "No" 2 "Yes" ;
label define V89       13 "Winter" 14 "Spring" 15 "Summer" 16 "Fall" ;
label define V91       1 "No" 2 "Yes" ;
label define V92       13 "Winter" 14 "Spring" 15 "Summer" 16 "Fall" ;
label define V94       1 "No" 2 "Yes" ;
label define V95       1 "Spouse" 2 "Girl/boy friend" 3 "Both" ;
label define V96       1 "Spouse" 2 "Girl/boy friend" ;
label define V97       0 "Less than 1 mo" ;
label define V98       1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V99       1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V100      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "Monthly" 5 "Weekly" ;
label define V101      0 "Less than 1 mo" ;
label define V102      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "Monthly" 5 "Weekly" ;
label define V103      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V104      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V105      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "Monthly" 5 "Weekly" ;
label define V106      0 "Less than 1 mo" ;
label define V107      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "Monthly" 5 "Weekly" ;
label define V108      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V109      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V110      0 "Less than once a wk" ;
label define V111      0 "Less than once a wk" ;
label define V112      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V113      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "Monthly" 5 "Weekly" ;
label define V114      0 "Less than once a mo" ;
label define V115      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "Monthly" 5 "Weekly" ;
label define V116      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V117      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V118      1 "Never" 2 "Several times a yr"
                       3 "Once or twice a mo" 4 "Once a wk"
                       5 "Several times a wk" ;
label define V119      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V120      99 "Anything 99 or more" 998 "Don't know" ;
label define V121      99 "Anything 99 or more" 998 "Don't know" ;
label define V122      99 "Anything 99 or more" 998 "Don't know" ;
label define V123      99 "Anything 99 or more" 998 "Don't know" ;
label define V124      99 "Anything 99 or more" 998 "Don't know" ;
label define V125      99 "Anything 99 or more" 998 "Don't know" ;
label define V126      99 "Anything 99 or more" 998 "Don't know" ;
label define V127      99 "Anything 99 or more" 998 "Don't know" ;
label define V128      99 "Anything 99 or more" 998 "Don't know" ;
label define V129      99 "Anything 99 or more" 998 "Don't know" ;
label define V130      99 "Anything 99 or more" 998 "Don't know" ;
label define V131      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V132      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V133      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V134      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V135      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V136      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V137      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V138      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V139      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V140      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V141      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V142      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V143      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V144      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V145      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V146      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V147      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V148      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V149      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V150      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V151      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V152      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V153      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V154      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V155      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V156      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V157      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V158      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V159      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V160      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V161      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V162      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V163      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V164      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V165      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V166      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V167      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V168      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V169      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V170      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V171      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V172      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V173      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V174      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V175      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V176      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V177      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V178      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V179      1 "Not important at all" 3 "Somewhat important"
                       5 "Very important" ;
label define V180      1 "Not important at all" 3 "Somewhat important"
                       5 "Very important" ;
label define V181      1 "Not important at all" 3 "Somewhat important"
                       5 "Very important" ;
label define V182      1 "Not important at all" 3 "Somewhat important"
                       5 "Very important" ;
label define V183      1 "Poor" 2 "Fair" 3 "Good" ;
label define V184      1 "Poor" 2 "Fair" 3 "Good" ;
label define V185      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V186      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V187      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V188      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V189      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V190      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V191      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V192      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V193      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V194      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V195      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V196      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V197      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V198      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V199      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V200      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V201      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V202      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V203      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V204      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V205      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V206      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V207      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V208      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V209      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V210      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V211      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V212      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V213      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V214      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V215      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V216      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V217      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V218      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V219      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V220      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V221      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V222      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V223      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V224      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V225      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V226      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V227      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V228      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V229      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V230      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V231      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V232      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V233      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V234      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V235      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V236      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V237      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V238      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V239      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V240      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V241      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V242      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V243      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V244      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V245      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V246      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V247      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V248      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V249      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V250      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V251      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V252      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V253      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V254      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V255      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V256      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V257      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V258      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V259      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V260      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V261      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V262      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V263      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V264      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V265      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V266      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V267      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V268      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V269      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V270      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V271      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V272      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V273      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V274      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V275      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V276      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V277      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V278      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V279      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V280      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V281      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V282      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V283      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V284      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V285      1 "Not wrong" 2 "A little wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V286      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V287      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V288      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V289      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V290      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V291      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V292      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V293      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V294      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V295      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V296      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V297      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V298      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V299      1 "No" 2 "Don't know" 3 "Yes" ;
label define V300      1 "No" 2 "Don't know" 3 "Yes" ;
label define V301      1 "No" 2 "Don't know" 3 "Yes" ;
label define V302      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V303      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V304      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V305      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V306      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V307      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V308      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V309      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V310      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V311      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V312      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V313      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V314      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V315      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V316      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V317      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V318      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V319      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V320      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V321      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V322      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V323      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V324      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V325      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V326      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V327      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V328      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V329      1 "Never" 2 "Once or twice" 3 "Several times"
                       4 "Often" ;
label define V330      1 "Never" 2 "Once or twice" 3 "Several times"
                       4 "Often" ;
label define V331      1 "Never" 2 "Once or twice" 3 "Several times"
                       4 "Often" ;
label define V332      1 "Never" 2 "Once or twice" 3 "Several times"
                       4 "Often" ;
label define V333      1 "Never" 2 "Once or twice" 3 "Several times"
                       4 "Often" ;
label define V334      1 "Never" 2 "Once or twice" 3 "Several times"
                       4 "Often" ;
label define V336      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V338      1 "No" 2 "Yes" ;
label define V339      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V340      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V342      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V344      1 "No" 2 "Yes" ;
label define V345      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V346      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V348      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V350      1 "No" 2 "Yes" ;
label define V351      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V352      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V354      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V355      1 "Car" 2 "Truck" 3 "Motorcycle" 4 "Other" ;
label define V356      1 "No" 2 "Yes" ;
label define V357      1 "Family member" 2 "Friend" 3 "Other" ;
label define V358      1 "Keys" 2 "Hot wired" 3 "Ignition" 4 "Other" ;
label define V359      1 "Riding" 2 "Keep" 3 "Keep parts" 4 "Sell"
                       5 "Sell parts" 6 "Other" ;
label define V360      1 "No" 2 "Yes" ;
label define V361      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V362      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V364      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V366      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V368      1 "No" 2 "Yes" ;
label define V369      1 "No" 2 "Yes" ;
label define V370      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V371      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V373      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V374      1 "Try to buy" 2 "Try to sell" 3 "Try to hold" 4 "Buy"
                       5 "Sell" 6 "Hold" 7 "Other" ;
label define V376      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V378      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V380      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V382      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V383      1 "24 hours or less" 2 "1-7 days" 3 "Longer than a wk" ;
label define V384      1 "No" 2 "Yes" ;
label define V385      1 "Relative's house" 2 "Friend's house" 3 "Other" ;
label define V386      1 "Less than a mile" 2 "1-10 miles"
                       3 "More than 10 miles" ;
label define V387      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V389      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V391      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V392      1 "Knife" 2 "Gun" 3 "Other" ;
label define V393      1 "Protection" 2 "Hurt someone" 3 "Just to have it"
                       4 "Other" ;
label define V394      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V396      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V398      1 "No" 2 "Yes" ;
label define V399      1 "No" 2 "Yes" ;
label define V400      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V401      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V403      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V404      1 "Hit" 2 "Beat/choked" 3 "Attacked w/weapon"
                       4 "Other" ;
label define V405      1 "No" 2 "Yes" ;
label define V406      1 "Knocked down" 2 "Bruised" 3 "Cut" 4 "Unconscious"
                       5 "Hospitalized" 6 "Other" ;
label define V407      1 "No" 2 "Yes" ;
label define V408      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V409      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V411      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V412      1 "Money" 2 "Drugs" 3 "Other" ;
label define V413      1 "No" 2 "Yes" ;
label define V414      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V416      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V417      1 "No" 2 "Yes" ;
label define V418      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V420      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V421      1 "1-2 people" 2 "3-5" 3 "More than 5 people" ;
label define V422      1 "l-2 people" 2 "3-5" 3 "More than 5 people" ;
label define V423      1 "No" 2 "Yes" ;
label define V424      1 "Knives" 2 "Chains" 3 "Guns" 4 "Hard knuckles"
                       5 "Other" ;
label define V425      1 "No" 2 "Yes" ;
label define V426      1 "Knocked down" 2 "Bruised" 3 "Cut" 4 "Unconscious"
                       5 "Hospitalized" 6 "Other" ;
label define V427      1 "No" 2 "Yes" ;
label define V428      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V429      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V431      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V433      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V435      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V437      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V439      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V441      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V443      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V445      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V446      1 "Money" 2 "Other" ;
label define V449      1 "No" 2 "Yes" ;
label define V450      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V451      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V453      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V454      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V456      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V457      1 "Actually hit" 2 "Tried" 3 "Threatened" ;
label define V458      1 "No" 2 "Yes" ;
label define V459      1 "Pushed" 2 "Caused them pain" 3 "Knocked down"
                       4 "Bruised" 5 "Cut" 6 "Unconscious" 7 "Hospitalized"
                       8 "Other" ;
label define V460      1 "No" 2 "Yes" ;
label define V461      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V462      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V464      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V465      1 "Actually hit" 2 "Tried" 3 "Threatened" ;
label define V466      1 "No" 2 "Yes" ;
label define V467      1 "Pushed" 2 "Caused them pain" 3 "Knocked down"
                       4 "Bruised" 5 "Cut" 6 "Unconscious" 7 "Hospitalized"
                       8 "Other" ;
label define V468      1 "No" 2 "Yes" ;
label define V469      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V470      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V472      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V473      1 "Actually hit" 2 "Tried" 3 "Threatened" ;
label define V474      1 "No" 2 "Yes" ;
label define V475      1 "Pushed" 2 "Caused them pain" 3 "Knocked down"
                       4 "Bruised" 5 "Cut" 6 "Unconscious" 7 "Hospitalized"
                       8 "Other" ;
label define V476      1 "No" 2 "Yes" ;
label define V477      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V478      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V480      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V482      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V484      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V486      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V487      1 "Stranger" 2 "Family member" 3 "Friend" 4 "Other" ;
label define V490      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V492      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V493      1 "Car" 2 "Truck" 3 "Motorcycle" 4 "Other" ;
label define V494      1 "Family member" 2 "Friend" 3 "Other" ;
label define V495      1 "Had the keys" 2 "Hot-wired" 3 "Keys in ignition"
                       4 "Other" ;
label define V496      1 "No" 2 "Yes" ;
label define V497      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V498      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V500      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V502      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V504      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V506      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V507      1 "Punched" 2 "Physical beating" 3 "Other" ;
label define V508      1 "Money" 2 "Other" ;
label define V509      1 "No" 2 "Yes" ;
label define V510      1 "Knocked down" 2 "Bruised" 3 "Cut" 4 "Unconscious"
                       5 "Hospitalized" 6 "Other" ;
label define V511      1 "No" 2 "Yes" ;
label define V512      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V513      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V515      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V516      1 "Punched" 2 "Physical beating" 3 "Other" ;
label define V517      1 "Money" 2 "Other" ;
label define V518      1 "No" 2 "Yes" ;
label define V519      1 "Knocked down" 2 "Bruised" 3 "Cut" 4 "Unconscious"
                       5 "Hospitalized" 6 "Other" ;
label define V520      1 "No" 2 "Yes" ;
label define V521      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V522      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V524      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V526      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V527      1 "Punched" 2 "Physical beating" 3 "Other" ;
label define V528      1 "Money" 2 "Other" ;
label define V529      1 "No" 2 "Yes" ;
label define V530      1 "Knocked down" 2 "Bruised" 3 "Cut" 4 "Unconscious"
                       5 "Hospitalized" 6 "Other" ;
label define V531      1 "No" 2 "Yes" ;
label define V532      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V533      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V535      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V537      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V539      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V540      1 "No" 2 "Yes" ;
label define V541      1 "No" 2 "Yes" ;
label define V542      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V543      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V545      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V546      1 "No" 2 "Yes" ;
label define V548      1 "No" 2 "Yes" ;
label define V549      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V550      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V552      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V553      1 "Building" 2 "Vehicle" 3 "House" 4 "Other" ;
label define V554      1 "Broke in" 2 "Tried" 3 "Door open" ;
label define V555      1 "Look around" 2 "Steal" 3 "Other" ;
label define V556      1 "No" 2 "Yes" ;
label define V557      1 "Drinking" 2 "Drugs" 3 "Both" ;
label define V558      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V560      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V562      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V563      1 "Part of day" 2 "All day" ;
label define V565      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V567      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V569      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V570      1 "Stranger" 2 "Family member" 3 "Friend" 4 "Other" ;
label define V572      1 "Inappropriate" 2 "Trivial" 3 "Serious" ;
label define V574      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V576      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V578      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V579      1 "No" 2 "yes" ;
label define V582      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V583      1 "Yes" 2 "No" ;
label define V585      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V586      1 "Yes" 2 "No" ;
label define V588      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V589      1 "Yes" 2 "No" ;
label define V590      1 "No" 2 "Yes" ;
label define V591      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V592      1 "Yes" 2 "No" ;
label define V597      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V598      1 "Yes" 2 "No" ;
label define V600      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V601      1 "Yes" 2 "No" ;
label define V603      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V604      1 "Yes" 2 "No" ;
label define V606      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V607      1 "Yes" 2 "No" ;
label define V609      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V610      1 "Yes" 2 "No" ;
label define V612      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V613      1 "Yes" 2 "No" ;
label define V615      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V616      1 "Yes" 2 "No" ;
label define V618      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V619      1 "Yes" 2 "No" ;
label define V621      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V622      1 "Yes" 2 "No" ;
label define V624      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V625      1 "Yes" 2 "No" ;
label define V626      1 "THC" 2 "Quaaludes" 3 "Cough medicine"
                       4 "Robitussin" 5 "Sominex" 6 "Sudafed" 7 "No-Doze"
                       8 "Demerol" 9 "Weight pills" 10 "Coricidin"
                       11 "Mushrooms" 13 "Pam" 14 "Allergy medicine"
                       99 "Other" ;
label define V628      1 "Never" 2 "Once or twice" 3 "Once every 2-3 mos"
                       4 "Once a mo" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2-3 times a wk" 8 "Once a day" 9 "2-3 times a day" ;
label define V629      1 "Yes" 2 "No" ;
label define V630      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V631      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V632      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V633      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V634      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V635      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V636      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V637      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V638      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V639      1 "Never" 2 "Once or twice" 3 "3 or 4 times"
                       4 "5 or 6 times" 5 "More than 6 times" ;
label define V640      1 "No" 2 "Yes" ;
label define V641      1 "No" 2 "Yes" ;
label define V642      1 "Yes" 2 "No" ;
label define V643      1 "Yes" 2 "No" ;
label define V644      1 "Yes" 2 "No" ;
label define V645      1 "Yes" 2 "No" ;
label define V646      1 "Yes" 2 "No" ;
label define V647      1 "Yes" 2 "No" ;
label define V648      1 "Yes" 2 "No" ;
label define V649      1 "Yes" 2 "No" ;
label define V650      1 "Yes" 2 "No" ;
label define V651      1 "Yes" 2 "No" ;
label define V652      1 "Yes" 2 "No" ;
label define V653      1 "Yes" 2 "No" ;
label define V654      1 "No" 2 "Yes" ;
label define V655      1 "No" 2 "Yes" ;
label define V660      1 "No" 2 "Yes" ;
label define V662      1 "No" 2 "Yes" ;
label define V663      1 "No" 2 "Yes" ;
label define V664      1 "No" 2 "Yes" ;
label define V665      1 "No" 2 "Yes" ;
label define V666      1 "No" 2 "Yes" ;
label define V667      1 "No" 2 "Yes" ;
label define V668      1 "No" 2 "Yes" ;
label define V669      1 "No" 2 "Yes" ;
label define V670      1 "No" 2 "Yes" ;
label define V672      1 "No" 2 "Yes" ;
label define V673      1 "No" 2 "Yes" ;
label define V674      1 "No" 2 "Yes" ;
label define V675      1 "No" 2 "Yes" ;
label define V676      1 "No" 2 "Yes" ;
label define V677      1 "No" 2 "Yes" ;
label define V678      1 "No" 2 "Yes" ;
label define V679      1 "No" 2 "Yes" ;
label define V680      1 "No" 2 "Yes" ;
label define V688      1 "No" 2 "Yes" ;
label define V690      1 "No" 2 "Yes" ;
label define V691      1 "Drugs" ;
label define V692      1 "Sex" ;
label define V696      1 "Friends" ;
label define V697      1 "Drugs/alcohol" ;
label define V698      1 "Family" ;
label define V699      1 "Activities" ;
label define V700      1 "School" ;
label define V701      1 "Other" ;
label define V702      1 "Good understand" 2 "Poor understand"
                       3 "Fair understand" ;
label define V703      1 "Not at all anxious" 2 "Somewhat anxious"
                       3 "Very anxious" ;
label define V704      1 "No" 2 "Yes" ;
label define V705      1 "Very low" 2 "Below average" 3 "Average"
                       4 "Above average" 5 "Very high" ;
label define V706      1 "Diff w/language" ;
label define V707      1 "Diff w/questions" ;
label define V708      1 "Interruptions" ;
label define V709      1 "Temp breakoff" ;
label define V710      1 "Breakoff" ;
label define V711      1 "Other" ;
label define V712      1 "Relaxed" 2 "Tense" 3 "Other" ;
label define V713      1 "No" 2 "Yes" ;
label define V714      0 "Resp not in SMSA" 1 "Resp in an SMSA" ;
label define V715      1 "SMSA" 2 "Urbanized area" 3 "SMSA/urban area"
                       4 "Other inc place" 5 "Not inc" ;
label define V716      0 "Under 200" 1 "200-499" 2 "500-999" 3 "1,000-1,499"
                       4 "1,500-1,999" 5 "2,000-2,499" 6 "2,500-4,999"
                       7 "5,000-9,999" 8 "10,000-19,999" 9 "20,000-24,999"
                       10 "25,000-49,999" 11 "50,000-99,999"
                       12 "100,000-249,999" 13 "250,000-499,999"
                       14 "500,000-999,999" 15 "1,000,000 or more" ;
label define V717      1 "Urban" 2 "Suburban" 3 "Rural" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace V1 = . if (V1 == -1)
replace V6 = . if (V6 == -1)
replace V7 = . if (V7 == -1)
replace V8 = . if (V8 == -1)
replace V9 = . if (V9 == -1)
replace V10 = . if (V10 == -1)
replace V11 = . if (V11 == -1)
replace V12 = . if (V12 == -1)
replace V13 = . if (V13 == -1)
replace V14 = . if (V14 == -1)
replace V15 = . if (V15 == -1)
replace V16 = . if (V16 == -1)
replace V17 = . if (V17 == -1)
replace V18 = . if (V18 == -1)
replace V19 = . if (V19 == -1)
replace V20 = . if (V20 == -1)
replace V21 = . if (V21 == -1)
replace V22 = . if (V22 == -1)
replace V23 = . if (V23 == -1)
replace V24 = . if (V24 == -1)
replace V25 = . if (V25 == -1)
replace V26 = . if (V26 == -1)
replace V27 = . if (V27 == -1)
replace V28 = . if (V28 == -1)
replace V29 = . if (V29 == -1)
replace V30 = . if (V30 == -1)
replace V31 = . if (V31 == -1)
replace V32 = . if (V32 == -1)
replace V33 = . if (V33 == -1)
replace V34 = . if (V34 == -1)
replace V35 = . if (V35 == -1)
replace V36 = . if (V36 == -1)
replace V37 = . if (V37 == -1)
replace V38 = . if (V38 == -1)
replace V39 = . if (V39 == -1)
replace V40 = . if (V40 == -1)
replace V41 = . if (V41 == -1)
replace V42 = . if (V42 == -1)
replace V43 = . if (V43 == -1)
replace V44 = . if (V44 == -1)
replace V45 = . if (V45 == -1)
replace V46 = . if (V46 == -1)
replace V47 = . if (V47 == -1)
replace V48 = . if (V48 == -1)
replace V49 = . if (V49 == -1)
replace V50 = . if (V50 == -1)
replace V51 = . if (V51 == -1)
replace V52 = . if (V52 == -1)
replace V53 = . if (V53 == -1)
replace V54 = . if (V54 == -1)
replace V55 = . if (V55 == -1)
replace V56 = . if (V56 == -1)
replace V57 = . if (V57 == -1)
replace V58 = . if (V58 == -1)
replace V60 = . if (V60 == -1)
replace V62 = . if (V62 == -1)
replace V63 = . if (V63 == -1)
replace V64 = . if (V64 == -1)
replace V65 = . if (V65 == -1)
replace V66 = . if (V66 == -1)
replace V67 = . if (V67 == -1)
replace V68 = . if (V68 == -1)
replace V69 = . if (V69 == -1)
replace V70 = . if (V70 == -1)
replace V71 = . if (V71 == -1)
replace V72 = . if (V72 == -1)
replace V73 = . if (V73 == -1)
replace V74 = . if (V74 == -1)
replace V75 = . if (V75 == -1)
replace V76 = . if (V76 == -1)
replace V77 = . if (V77 == -1)
replace V78 = . if (V78 == -1)
replace V79 = . if (V79 == -1)
replace V80 = . if (V80 == -1)
replace V81 = . if (V81 == -1)
replace V82 = . if (V82 == -1)
replace V83 = . if (V83 == -1)
replace V84 = . if (V84 == -1)
replace V85 = . if (V85 == -1)
replace V86 = . if (V86 == -1)
replace V87 = . if (V87 == -1)
replace V88 = . if (V88 == -1)
replace V89 = . if (V89 == -1)
replace V90 = . if (V90 == -1)
replace V91 = . if (V91 == -1)
replace V92 = . if (V92 == -1)
replace V93 = . if (V93 == -1)
replace V94 = . if (V94 == -1)
replace V95 = . if (V95 == -1)
replace V96 = . if (V96 == -1)
replace V97 = . if (V97 == -1)
replace V98 = . if (V98 == -1)
replace V99 = . if (V99 == -1)
replace V100 = . if (V100 == -1)
replace V101 = . if (V101 == -1)
replace V102 = . if (V102 == -1)
replace V103 = . if (V103 == -1)
replace V104 = . if (V104 == -1)
replace V105 = . if (V105 == -1)
replace V106 = . if (V106 == -1)
replace V107 = . if (V107 == -1)
replace V108 = . if (V108 == -1)
replace V109 = . if (V109 == -1)
replace V110 = . if (V110 == -1)
replace V111 = . if (V111 == -1)
replace V112 = . if (V112 == -1)
replace V113 = . if (V113 == -1)
replace V114 = . if (V114 == -1)
replace V115 = . if (V115 == -1)
replace V116 = . if (V116 == -1)
replace V117 = . if (V117 == -1)
replace V118 = . if (V118 == -1)
replace V119 = . if (V119 == -1)
replace V120 = . if (V120 == -1)
replace V121 = . if (V121 == -1)
replace V122 = . if (V122 == -1)
replace V123 = . if (V123 == -1)
replace V124 = . if (V124 == -1)
replace V125 = . if (V125 == -1)
replace V126 = . if (V126 == -1)
replace V127 = . if (V127 == -1)
replace V128 = . if (V128 == -1)
replace V129 = . if (V129 == -1)
replace V130 = . if (V130 == -1)
replace V131 = . if (V131 == -1)
replace V132 = . if (V132 == -1)
replace V133 = . if (V133 == -1)
replace V134 = . if (V134 == -1)
replace V135 = . if (V135 == -1)
replace V136 = . if (V136 == -1)
replace V137 = . if (V137 == -1)
replace V138 = . if (V138 == -1)
replace V139 = . if (V139 == -1)
replace V140 = . if (V140 == -1)
replace V141 = . if (V141 == -1)
replace V142 = . if (V142 == -1)
replace V143 = . if (V143 == -1)
replace V144 = . if (V144 == -1)
replace V145 = . if (V145 == -1)
replace V146 = . if (V146 == -1)
replace V147 = . if (V147 == -1)
replace V148 = . if (V148 == -1)
replace V149 = . if (V149 == -1)
replace V150 = . if (V150 == -1)
replace V151 = . if (V151 == -1)
replace V152 = . if (V152 == -1)
replace V153 = . if (V153 == -1)
replace V154 = . if (V154 == -1)
replace V155 = . if (V155 == -1)
replace V156 = . if (V156 == -1)
replace V157 = . if (V157 == -1)
replace V158 = . if (V158 == -1)
replace V159 = . if (V159 == -1)
replace V160 = . if (V160 == -1)
replace V161 = . if (V161 == -1)
replace V162 = . if (V162 == -1)
replace V163 = . if (V163 == -1)
replace V164 = . if (V164 == -1)
replace V165 = . if (V165 == -1)
replace V166 = . if (V166 == -1)
replace V167 = . if (V167 == -1)
replace V168 = . if (V168 == -1)
replace V169 = . if (V169 == -1)
replace V170 = . if (V170 == -1)
replace V171 = . if (V171 == -1)
replace V172 = . if (V172 == -1)
replace V173 = . if (V173 == -1)
replace V174 = . if (V174 == -1)
replace V175 = . if (V175 == -1)
replace V176 = . if (V176 == -1)
replace V177 = . if (V177 == -1)
replace V178 = . if (V178 == -1)
replace V179 = . if (V179 == -1)
replace V180 = . if (V180 == -1)
replace V181 = . if (V181 == -1)
replace V182 = . if (V182 == -1)
replace V183 = . if (V183 == -1)
replace V184 = . if (V184 == -1)
replace V185 = . if (V185 == -1)
replace V186 = . if (V186 == -1)
replace V187 = . if (V187 == -1)
replace V188 = . if (V188 == -1)
replace V189 = . if (V189 == -1)
replace V190 = . if (V190 == -1)
replace V191 = . if (V191 == -1)
replace V192 = . if (V192 == -1)
replace V193 = . if (V193 == -1)
replace V194 = . if (V194 == -1)
replace V195 = . if (V195 == -1)
replace V196 = . if (V196 == -1)
replace V197 = . if (V197 == -1)
replace V198 = . if (V198 == -1)
replace V199 = . if (V199 == -1)
replace V200 = . if (V200 == -1)
replace V201 = . if (V201 == -1)
replace V202 = . if (V202 == -1)
replace V203 = . if (V203 == -1)
replace V204 = . if (V204 == -1)
replace V205 = . if (V205 == -1)
replace V206 = . if (V206 == -1)
replace V207 = . if (V207 == -1)
replace V208 = . if (V208 == -1)
replace V209 = . if (V209 == -1)
replace V210 = . if (V210 == -1)
replace V211 = . if (V211 == -1)
replace V212 = . if (V212 == -1)
replace V213 = . if (V213 == -1)
replace V214 = . if (V214 == -1)
replace V215 = . if (V215 == -1)
replace V216 = . if (V216 == -1)
replace V217 = . if (V217 == -1)
replace V218 = . if (V218 == -1)
replace V219 = . if (V219 == -1)
replace V220 = . if (V220 == -1)
replace V221 = . if (V221 == -1)
replace V222 = . if (V222 == -1)
replace V223 = . if (V223 == -1)
replace V224 = . if (V224 == -1)
replace V225 = . if (V225 == -1)
replace V226 = . if (V226 == -1)
replace V227 = . if (V227 == -1)
replace V228 = . if (V228 == -1)
replace V229 = . if (V229 == -1)
replace V230 = . if (V230 == -1)
replace V231 = . if (V231 == -1)
replace V232 = . if (V232 == -1)
replace V233 = . if (V233 == -1)
replace V234 = . if (V234 == -1)
replace V235 = . if (V235 == -1)
replace V236 = . if (V236 == -1)
replace V237 = . if (V237 == -1)
replace V238 = . if (V238 == -1)
replace V239 = . if (V239 == -1)
replace V240 = . if (V240 == -1)
replace V241 = . if (V241 == -1)
replace V242 = . if (V242 == -1)
replace V243 = . if (V243 == -1)
replace V244 = . if (V244 == -1)
replace V245 = . if (V245 == -1)
replace V246 = . if (V246 == -1)
replace V247 = . if (V247 == -1)
replace V248 = . if (V248 == -1)
replace V249 = . if (V249 == -1)
replace V250 = . if (V250 == -1)
replace V251 = . if (V251 == -1)
replace V252 = . if (V252 == -1)
replace V253 = . if (V253 == -1)
replace V254 = . if (V254 == -1)
replace V255 = . if (V255 == -1)
replace V256 = . if (V256 == -1)
replace V257 = . if (V257 == -1)
replace V258 = . if (V258 == -1)
replace V259 = . if (V259 == -1)
replace V260 = . if (V260 == -1)
replace V261 = . if (V261 == -1)
replace V262 = . if (V262 == -1)
replace V263 = . if (V263 == -1)
replace V264 = . if (V264 == -1)
replace V265 = . if (V265 == -1)
replace V266 = . if (V266 == -1)
replace V267 = . if (V267 == -1)
replace V268 = . if (V268 == -1)
replace V269 = . if (V269 == -1)
replace V270 = . if (V270 == -1)
replace V271 = . if (V271 == -1)
replace V272 = . if (V272 == -1)
replace V273 = . if (V273 == -1)
replace V274 = . if (V274 == -1)
replace V275 = . if (V275 == -1)
replace V276 = . if (V276 == -1)
replace V277 = . if (V277 == -1)
replace V278 = . if (V278 == -1)
replace V279 = . if (V279 == -1)
replace V280 = . if (V280 == -1)
replace V281 = . if (V281 == -1)
replace V282 = . if (V282 == -1)
replace V283 = . if (V283 == -1)
replace V284 = . if (V284 == -1)
replace V285 = . if (V285 == -1)
replace V286 = . if (V286 == -1)
replace V287 = . if (V287 == -1)
replace V288 = . if (V288 == -1)
replace V289 = . if (V289 == -1)
replace V290 = . if (V290 == -1)
replace V291 = . if (V291 == -1)
replace V292 = . if (V292 == -1)
replace V293 = . if (V293 == -1)
replace V294 = . if (V294 == -1)
replace V295 = . if (V295 == -1)
replace V296 = . if (V296 == -1)
replace V297 = . if (V297 == -1)
replace V298 = . if (V298 == -1)
replace V299 = . if (V299 == -1)
replace V300 = . if (V300 == -1)
replace V301 = . if (V301 == -1)
replace V302 = . if (V302 == -1)
replace V303 = . if (V303 == -1)
replace V304 = . if (V304 == -1)
replace V305 = . if (V305 == -1)
replace V306 = . if (V306 == -1)
replace V307 = . if (V307 == -1)
replace V308 = . if (V308 == -1)
replace V309 = . if (V309 == -1)
replace V310 = . if (V310 == -1)
replace V311 = . if (V311 == -1)
replace V312 = . if (V312 == -1)
replace V313 = . if (V313 == -1)
replace V314 = . if (V314 == -1)
replace V315 = . if (V315 == -1)
replace V316 = . if (V316 == -1)
replace V317 = . if (V317 == -1)
replace V318 = . if (V318 == -1)
replace V319 = . if (V319 == -1)
replace V320 = . if (V320 == -1)
replace V321 = . if (V321 == -1)
replace V322 = . if (V322 == -1)
replace V323 = . if (V323 == -1)
replace V324 = . if (V324 == -1)
replace V325 = . if (V325 == -1)
replace V326 = . if (V326 == -1)
replace V327 = . if (V327 == -1)
replace V328 = . if (V328 == -1)
replace V329 = . if (V329 == -1)
replace V330 = . if (V330 == -1)
replace V331 = . if (V331 == -1)
replace V332 = . if (V332 == -1)
replace V333 = . if (V333 == -1)
replace V334 = . if (V334 == -1)
replace V335 = . if (V335 == -1)
replace V336 = . if (V336 == -1)
replace V337 = . if (V337 == -1)
replace V338 = . if (V338 == -1)
replace V339 = . if (V339 == -1)
replace V340 = . if (V340 == -1)
replace V341 = . if (V341 == -1)
replace V342 = . if (V342 == -1)
replace V343 = . if (V343 == -1)
replace V344 = . if (V344 == -1)
replace V345 = . if (V345 == -1)
replace V346 = . if (V346 == -1)
replace V347 = . if (V347 == -1)
replace V348 = . if (V348 == -1)
replace V349 = . if (V349 == -1)
replace V350 = . if (V350 == -1)
replace V351 = . if (V351 == -1)
replace V352 = . if (V352 == -1)
replace V353 = . if (V353 == -1)
replace V354 = . if (V354 == -1)
replace V355 = . if (V355 == -1)
replace V356 = . if (V356 == -1)
replace V357 = . if (V357 == -1)
replace V358 = . if (V358 == -1)
replace V359 = . if (V359 == -1)
replace V360 = . if (V360 == -1)
replace V361 = . if (V361 == -1)
replace V362 = . if (V362 == -1)
replace V363 = . if (V363 == -1)
replace V364 = . if (V364 == -1)
replace V365 = . if (V365 == -1)
replace V366 = . if (V366 == -1)
replace V367 = . if (V367 == -1)
replace V368 = . if (V368 == -1)
replace V369 = . if (V369 == -1)
replace V370 = . if (V370 == -1)
replace V371 = . if (V371 == -1)
replace V372 = . if (V372 == -1)
replace V373 = . if (V373 == -1)
replace V374 = . if (V374 == -1)
replace V375 = . if (V375 == -1)
replace V376 = . if (V376 == -1)
replace V377 = . if (V377 == -1)
replace V378 = . if (V378 == -1)
replace V379 = . if (V379 == -1)
replace V380 = . if (V380 == -1)
replace V381 = . if (V381 == -1)
replace V382 = . if (V382 == -1)
replace V383 = . if (V383 == -1)
replace V384 = . if (V384 == -1)
replace V385 = . if (V385 == -1)
replace V386 = . if (V386 == -1)
replace V387 = . if (V387 == -1)
replace V388 = . if (V388 == -1)
replace V389 = . if (V389 == -1)
replace V390 = . if (V390 == -1)
replace V391 = . if (V391 == -1)
replace V392 = . if (V392 == -1)
replace V393 = . if (V393 == -1)
replace V394 = . if (V394 == -1)
replace V395 = . if (V395 == -1)
replace V396 = . if (V396 == -1)
replace V397 = . if (V397 == -1)
replace V398 = . if (V398 == -1)
replace V399 = . if (V399 == -1)
replace V400 = . if (V400 == -1)
replace V401 = . if (V401 == -1)
replace V402 = . if (V402 == -1)
replace V403 = . if (V403 == -1)
replace V404 = . if (V404 == -1)
replace V405 = . if (V405 == -1)
replace V406 = . if (V406 == -1)
replace V407 = . if (V407 == -1)
replace V408 = . if (V408 == -1)
replace V409 = . if (V409 == -1)
replace V410 = . if (V410 == -1)
replace V411 = . if (V411 == -1)
replace V412 = . if (V412 == -1)
replace V413 = . if (V413 == -1)
replace V414 = . if (V414 == -1)
replace V415 = . if (V415 == -1)
replace V416 = . if (V416 == -1)
replace V417 = . if (V417 == -1)
replace V418 = . if (V418 == -1)
replace V419 = . if (V419 == -1)
replace V420 = . if (V420 == -1)
replace V421 = . if (V421 == -1)
replace V422 = . if (V422 == -1)
replace V423 = . if (V423 == -1)
replace V424 = . if (V424 == -1)
replace V425 = . if (V425 == -1)
replace V426 = . if (V426 == -1)
replace V427 = . if (V427 == -1)
replace V428 = . if (V428 == -1)
replace V429 = . if (V429 == -1)
replace V430 = . if (V430 == -1)
replace V431 = . if (V431 == -1)
replace V432 = . if (V432 == -1)
replace V433 = . if (V433 == -1)
replace V434 = . if (V434 == -1)
replace V435 = . if (V435 == -1)
replace V436 = . if (V436 == -1)
replace V437 = . if (V437 == -1)
replace V438 = . if (V438 == -1)
replace V439 = . if (V439 == -1)
replace V440 = . if (V440 == -1)
replace V441 = . if (V441 == -1)
replace V442 = . if (V442 == -1)
replace V443 = . if (V443 == -1)
replace V444 = . if (V444 == -1)
replace V445 = . if (V445 == -1)
replace V446 = . if (V446 == -1)
replace V447 = . if (V447 == -1)
replace V448 = . if (V448 == -1)
replace V449 = . if (V449 == -1)
replace V450 = . if (V450 == -1)
replace V451 = . if (V451 == -1)
replace V452 = . if (V452 == -1)
replace V453 = . if (V453 == -1)
replace V454 = . if (V454 == -1)
replace V455 = . if (V455 == -1)
replace V456 = . if (V456 == -1)
replace V457 = . if (V457 == -1)
replace V458 = . if (V458 == -1)
replace V459 = . if (V459 == -1)
replace V460 = . if (V460 == -1)
replace V461 = . if (V461 == -1)
replace V462 = . if (V462 == -1)
replace V463 = . if (V463 == -1)
replace V464 = . if (V464 == -1)
replace V465 = . if (V465 == -1)
replace V466 = . if (V466 == -1)
replace V467 = . if (V467 == -1)
replace V468 = . if (V468 == -1)
replace V469 = . if (V469 == -1)
replace V470 = . if (V470 == -1)
replace V471 = . if (V471 == -1)
replace V472 = . if (V472 == -1)
replace V473 = . if (V473 == -1)
replace V474 = . if (V474 == -1)
replace V475 = . if (V475 == -1)
replace V476 = . if (V476 == -1)
replace V477 = . if (V477 == -1)
replace V478 = . if (V478 == -1)
replace V479 = . if (V479 == -1)
replace V480 = . if (V480 == -1)
replace V481 = . if (V481 == -1)
replace V482 = . if (V482 == -1)
replace V483 = . if (V483 == -1)
replace V484 = . if (V484 == -1)
replace V485 = . if (V485 == -1)
replace V486 = . if (V486 == -1)
replace V487 = . if (V487 == -1)
replace V488 = . if (V488 == -1)
replace V489 = . if (V489 == -1)
replace V490 = . if (V490 == -1)
replace V491 = . if (V491 == -1)
replace V492 = . if (V492 == -1)
replace V493 = . if (V493 == -1)
replace V494 = . if (V494 == -1)
replace V495 = . if (V495 == -1)
replace V496 = . if (V496 == -1)
replace V497 = . if (V497 == -1)
replace V498 = . if (V498 == -1)
replace V499 = . if (V499 == -1)
replace V500 = . if (V500 == -1)
replace V501 = . if (V501 == -1)
replace V502 = . if (V502 == -1)
replace V503 = . if (V503 == -1)
replace V504 = . if (V504 == -1)
replace V505 = . if (V505 == -1)
replace V506 = . if (V506 == -1)
replace V507 = . if (V507 == -1)
replace V508 = . if (V508 == -1)
replace V509 = . if (V509 == -1)
replace V510 = . if (V510 == -1)
replace V511 = . if (V511 == -1)
replace V512 = . if (V512 == -1)
replace V513 = . if (V513 == -1)
replace V514 = . if (V514 == -1)
replace V515 = . if (V515 == -1)
replace V516 = . if (V516 == -1)
replace V517 = . if (V517 == -1)
replace V518 = . if (V518 == -1)
replace V519 = . if (V519 == -1)
replace V520 = . if (V520 == -1)
replace V521 = . if (V521 == -1)
replace V522 = . if (V522 == -1)
replace V523 = . if (V523 == -1)
replace V524 = . if (V524 == -1)
replace V525 = . if (V525 == -1)
replace V526 = . if (V526 == -1)
replace V527 = . if (V527 == -1)
replace V528 = . if (V528 == -1)
replace V529 = . if (V529 == -1)
replace V530 = . if (V530 == -1)
replace V531 = . if (V531 == -1)
replace V532 = . if (V532 == -1)
replace V533 = . if (V533 == -1)
replace V534 = . if (V534 == -1)
replace V535 = . if (V535 == -1)
replace V536 = . if (V536 == -1)
replace V537 = . if (V537 == -1)
replace V538 = . if (V538 == -1)
replace V539 = . if (V539 == -1)
replace V540 = . if (V540 == -1)
replace V541 = . if (V541 == -1)
replace V542 = . if (V542 == -1)
replace V543 = . if (V543 == -1)
replace V544 = . if (V544 == -1)
replace V545 = . if (V545 == -1)
replace V546 = . if (V546 == -1)
replace V547 = . if (V547 == -1)
replace V548 = . if (V548 == -1)
replace V549 = . if (V549 == -1)
replace V550 = . if (V550 == -1)
replace V551 = . if (V551 == -1)
replace V552 = . if (V552 == -1)
replace V553 = . if (V553 == -1)
replace V554 = . if (V554 == -1)
replace V555 = . if (V555 == -1)
replace V556 = . if (V556 == -1)
replace V557 = . if (V557 == -1)
replace V558 = . if (V558 == -1)
replace V559 = . if (V559 == -1)
replace V560 = . if (V560 == -1)
replace V561 = . if (V561 == -1)
replace V562 = . if (V562 == -1)
replace V563 = . if (V563 == -1)
replace V564 = . if (V564 == -1)
replace V565 = . if (V565 == -1)
replace V566 = . if (V566 == -1)
replace V567 = . if (V567 == -1)
replace V568 = . if (V568 == -1)
replace V569 = . if (V569 == -1)
replace V570 = . if (V570 == -1)
replace V571 = . if (V571 == -1)
replace V572 = . if (V572 == -1)
replace V573 = . if (V573 == -1)
replace V574 = . if (V574 == -1)
replace V575 = . if (V575 == -1)
replace V576 = . if (V576 == -1)
replace V577 = . if (V577 == -1)
replace V578 = . if (V578 == -1)
replace V579 = . if (V579 == -1)
replace V580 = . if (V580 == -1)
replace V581 = . if (V581 == -1)
replace V582 = . if (V582 == -1)
replace V584 = . if (V584 == -1)
replace V585 = . if (V585 == -1)
replace V587 = . if (V587 == -1)
replace V588 = . if (V588 == -1)
replace V590 = . if (V590 == -1)
replace V591 = . if (V591 == -1)
replace V593 = . if (V593 == -1)
replace V594 = . if (V594 == -1)
replace V595 = . if (V595 == -1)
replace V596 = . if (V596 == -1)
replace V597 = . if (V597 == -1)
replace V599 = . if (V599 == -1)
replace V600 = . if (V600 == -1)
replace V602 = . if (V602 == -1)
replace V603 = . if (V603 == -1)
replace V605 = . if (V605 == -1)
replace V606 = . if (V606 == -1)
replace V608 = . if (V608 == -1)
replace V609 = . if (V609 == -1)
replace V611 = . if (V611 == -1)
replace V612 = . if (V612 == -1)
replace V614 = . if (V614 == -1)
replace V615 = . if (V615 == -1)
replace V617 = . if (V617 == -1)
replace V618 = . if (V618 == -1)
replace V620 = . if (V620 == -1)
replace V621 = . if (V621 == -1)
replace V623 = . if (V623 == -1)
replace V624 = . if (V624 == -1)
replace V626 = . if (V626 == -1)
replace V627 = . if (V627 == -1)
replace V628 = . if (V628 == -1)
replace V630 = . if (V630 == -1)
replace V631 = . if (V631 == -1)
replace V632 = . if (V632 == -1)
replace V633 = . if (V633 == -1)
replace V634 = . if (V634 == -1)
replace V635 = . if (V635 == -1)
replace V636 = . if (V636 == -1)
replace V637 = . if (V637 == -1)
replace V638 = . if (V638 == -1)
replace V639 = . if (V639 == -1)
replace V640 = . if (V640 == -1)
replace V641 = . if (V641 == -1)
replace V654 = . if (V654 == -1)
replace V655 = . if (V655 == -1)
replace V656 = . if (V656 == -1)
replace V657 = . if (V657 == -1)
replace V658 = . if (V658 == -1)
replace V659 = . if (V659 == -1)
replace V660 = . if (V660 == -1)
replace V661 = . if (V661 == -1)
replace V662 = . if (V662 == -1)
replace V663 = . if (V663 == -1)
replace V664 = . if (V664 == -1)
replace V665 = . if (V665 == -1)
replace V666 = . if (V666 == -1)
replace V667 = . if (V667 == -1)
replace V668 = . if (V668 == -1)
replace V669 = . if (V669 == -1)
replace V670 = . if (V670 == -1)
replace V671 = . if (V671 == -1)
replace V672 = . if (V672 == -1)
replace V673 = . if (V673 == -1)
replace V674 = . if (V674 == -1)
replace V675 = . if (V675 == -1)
replace V676 = . if (V676 == -1)
replace V677 = . if (V677 == -1)
replace V678 = . if (V678 == -1)
replace V679 = . if (V679 == -1)
replace V680 = . if (V680 == -1)
replace V681 = . if (V681 == -1)
replace V682 = . if (V682 == -1)
replace V683 = . if (V683 == -1)
replace V684 = . if (V684 == -1)
replace V685 = . if (V685 == -1)
replace V686 = . if (V686 == -1)
replace V687 = . if (V687 == -1)
replace V688 = . if (V688 == -1)
replace V689 = . if (V689 == -1)
replace V690 = . if (V690 == -1)
replace V691 = . if (V691 == -1)
replace V692 = . if (V692 == -1)
replace V693 = . if (V693 == -1)
replace V694 = . if (V694 == -1)
replace V695 = . if (V695 == -1)
replace V696 = . if (V696 == -1)
replace V697 = . if (V697 == -1)
replace V698 = . if (V698 == -1)
replace V699 = . if (V699 == -1)
replace V700 = . if (V700 == -1)
replace V701 = . if (V701 == -1)
replace V702 = . if (V702 == -1)
replace V703 = . if (V703 == -1)
replace V704 = . if (V704 == -1)
replace V705 = . if (V705 == -1)
replace V706 = . if (V706 == -1)
replace V707 = . if (V707 == -1)
replace V708 = . if (V708 == -1)
replace V709 = . if (V709 == -1)
replace V710 = . if (V710 == -1)
replace V711 = . if (V711 == -1)
replace V712 = . if (V712 == -1)
replace V713 = . if (V713 == -1)
replace V714 = . if (V714 == -1)
replace V715 = . if (V715 == -1)
replace V716 = . if (V716 == -1)
replace V717 = . if (V717 == -1)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

